@@ -33,6 +33,7 @@ import { selectInfrastructureNamespaces } from '../../store/InfrastructureNamesp
 import { safeLoad } from 'js-yaml';
 import updateDevfileMetadata, { FactorySource } from './updateDevfileMetadata';
 import { DEVWORKSPACE_DEVFILE_SOURCE } from '../../services/workspace-client/devWorkspaceClient';
+import { getErrorMessage } from '../../services/helpers/getErrorMessage';
 
 const WS_ATTRIBUTES_TO_SAVE: string[] = ['workspaceDeploymentLabels', 'workspaceDeploymentAnnotations', 'policies.create'];
 
@@ -61,7 +62,7 @@ type Props =
 type State = {
   search?: string;
   location?: string;
-  devfileLocationInfo?: string;
+  resolvedDevfileMessage?: string;
   currentStep: LoadFactorySteps;
   hasError: boolean;
   createPolicy: CreatePolicy;
@@ -266,8 +267,7 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
         this.resolvePrivateDevfile(e.attributes.oauth_authentication_url, location);
         return;
       }
-
-      this.showAlert('Failed to resolve a devfile. ' + (e.message || ''));
+      this.showAlert('Failed to resolve a devfile. ' + getErrorMessage(e));
       return;
     }
     if (this.factoryResolver.resolver?.location !== location) {
@@ -276,10 +276,21 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
     }
     const { source } = this.factoryResolver.resolver;
     const searchParam = new window.URLSearchParams(this.state.search);
-    const devfileLocationInfo = !source || source === 'repo' ?
-      `${searchParam.get('url')}` :
-      `\`${source}\` in github repo ${location}`;
-    this.setState({ devfileLocationInfo });
+    let resolvedDevfileMessage: string;
+    // source tells where devfile comes from
+    //  - no source: the url to raw content is used
+    //  - repo: means no devfile is found and default is generated
+    //  - any other - devfile is found in repository as filename from the value
+    if (!source) {
+      resolvedDevfileMessage = `Devfile loaded from ${searchParam.get('url')}`;
+    } else {
+      if (source === 'repo') {
+        resolvedDevfileMessage = `Devfile could not be found in ${searchParam.get('url')}. Applying the default configuration`;
+      } else {
+        resolvedDevfileMessage = `Devfile found in repo ${searchParam.get('url')} as '${source}'. Applying it`;
+      }
+    }
+    this.setState({ resolvedDevfileMessage });
     return this.getTargetDevfile();
   }
 
@@ -498,7 +509,7 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
 
   render() {
     const { workspace } = this.props;
-    const { currentStep, devfileLocationInfo, hasError } = this.state;
+    const { currentStep, resolvedDevfileMessage, hasError } = this.state;
     const workspaceName = workspace ? workspace.name : '';
     const workspaceId = workspace ? workspace.id : '';
 
@@ -506,7 +517,7 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
       <FactoryLoader
         currentStep={currentStep}
         hasError={hasError}
-        devfileLocationInfo={devfileLocationInfo}
+        resolvedDevfileMessage={resolvedDevfileMessage}
         workspaceId={workspaceId}
         workspaceName={workspaceName}
         callbacks={this.factoryLoaderCallbacks}
