@@ -26,6 +26,7 @@ import { V1alpha2DevWorkspace, V1alpha2DevWorkspaceTemplate, V1alpha2DevWorkspac
 import { InversifyBinding } from '@eclipse-che/che-theia-devworkspace-handler/lib/inversify/inversify-binding';
 import { CheTheiaPluginsDevfileResolver } from '@eclipse-che/che-theia-devworkspace-handler/lib/devfile/che-theia-plugins-devfile-resolver';
 import { SidecarPolicy } from '@eclipse-che/che-theia-devworkspace-handler/lib/api/devfile-context';
+import { getStatus } from '../workspaceAdapter/helper';
 export interface IStatusUpdate {
   error?: string;
   message?: string;
@@ -163,15 +164,20 @@ export class DevWorkspaceClient extends WorkspaceClient {
     }
     console.debug('Loading devfile', devfile, 'with optional .che/che-theia-plugins.yaml', cheTheiaPluginsContent, 'and .vscode/extensions.json', vscodeExtensionsJsonContent, 'with sidecar policy', sidecarPolicy);
     // call library to update devWorkspace and add optional templates
-    await cheTheiaPluginsDevfileResolver.handle({
-      devfile,
-      cheTheiaPluginsContent,
-      vscodeExtensionsJsonContent,
-      devWorkspace,
-      devWorkspaceTemplates,
-      sidecarPolicy,
-      suffix: workspaceId,
-    });
+    try {
+      await cheTheiaPluginsDevfileResolver.handle({
+        devfile,
+        cheTheiaPluginsContent,
+        vscodeExtensionsJsonContent,
+        devWorkspace,
+        devWorkspaceTemplates,
+        sidecarPolicy,
+        suffix: workspaceId,
+      });
+    } catch (error) {
+      console.error(error);
+      throw new Error(`Unable to update the devWorkspace with the devfile resolver: ${error.message}`);
+    }
     console.debug('Devfile updated to', devfile, ' and templates updated to', devWorkspaceTemplates);
 
     await Promise.all(devWorkspaceTemplates.map(async template => {
@@ -449,7 +455,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
   }
 
   checkForDevWorkspaceError(devworkspace: IDevWorkspace) {
-    const currentPhase = devworkspace.status?.phase;
+    const currentPhase = getStatus(devworkspace);
     if (currentPhase && currentPhase === DevWorkspaceStatus.FAILED) {
       const message = devworkspace.status.message;
       if (message) {
