@@ -42,11 +42,29 @@ server.register(fastifyStatic, {
   lastModified: true,
   prefix: '/dashboard/',
 });
+
 server.get('/', async (request, reply) => {
   reply.code(204);
   return reply.send();
 });
 
+server.get('/dashboard', async (request, reply) => {
+  return reply.redirect('/dashboard/');
+});
+
+const doNotCache = [
+  '/dashboard/',
+  '/dashboard/index.html',
+  '/dashboard/assets/branding/product.json',
+];
+server.addHook('onSend', (request, reply, payload: any, done) => {
+  const err = null;
+  if (doNotCache.includes(request.url)) {
+    reply.header('cache-control', 'no-store, max-age=0');
+  }
+  done(err, payload);
+});
+
 server.listen(port, hostname, (err, address) => {
   if (err) throw err;
-})
+});
